@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import gobject
 import hildon
 import hildondesktop
@@ -37,7 +38,7 @@ imagedir = "/opt/comic-widget/images/"
 dbdir = "/home/user/.comic-widget/"
 activecomics = dbdir + "activecomics.cfg"
 comiccache = "/home/user/MyDocs/.comics/"
-defaultcomics = ['xkcd','wulff','sinfest']
+defaultcomics = ['xkcd','dilbert','sinfest']
 comics = {
 		"9_chickweed_lanecomicscom":{"name":"9 Chickweed Lane","link":"http://comics.com/9_chickweed_lane/","start":"2010-09-21","dbfile":dbdir + "comicdb.9chickweedlane.csv"},
 		"agnescomicscom":{"name":"Agnes","link":"http://comics.com/agnes/","start":"2010-09-21","dbfile":dbdir + "comicdb.agnes.csv"},
@@ -140,7 +141,6 @@ comics = {
 		"wizard_of_idcomicscom":{"name":"Wizard of Id","link":'http://comics.com/wizard_of_id/',"start":"2010-09-21","dbfile":dbdir + "comicdb.wizardofid.csv"},
 		"working_dazecomicscom":{"name":"Working Daze","link":'http://comics.com/working_daze/',"start":"2010-09-21","dbfile":dbdir + "comicdb.workingdaze.csv"},
 		"working_it_outcomicscom":{"name":"Working It Out","link":'http://comics.com/working_it_out/',"start":"2010-09-21","dbfile":dbdir + "comicdb.workingitout.csv"},
-		"wulff":{"name":"Wulffmorgenthaler","link":"http://wulffmorgenthaler.com/","start":"d588eadf-6b30-41a3-bda3-10f1e767fbc6","dbfile":dbdir + "comicdb.wulff.csv"},
 		"xkcd":{"name":"xkcd","link":"http://xkcd.org/","start":795,"dbfile":dbdir + "comicdb.xkcd.csv"},
 		"zack_hillcomicscom":{"name":"Zack Hill","link":'http://comics.com/zack_hill/',"start":"2010-09-21","dbfile":dbdir + "comicdb.zackhill.csv"},
 		"amazing_spidermanckdm":{"name":"The Amazing Spider-Man","link":'http://content.comicskingdom.net/Spiderman/',"start":"20100921","dbfile":dbdir + "comicdb.spiderman.csv"},
@@ -211,6 +211,7 @@ comics = {
 		"fingerporihesari":{"name":"Fingerpori","link":"http://www.hs.fi/fingerpori/","start":"1135260260580","dbfile":dbdir + "comicdb.fingerpori.csv"},
 		"exocomics":{"name":"Extra Ordinary","link":"http://exocomics.com/","start":"146","dbfile":dbdir + "comicdb.exocomics.csv"},
 		"qcontent":{"name":"Questionable Content","link":"http://questionablecontent.net/view.php?comic=","start":"1758","dbfile":dbdir + "comicdb.qcontent.csv"},
+		"wulff_new":{"name":"Wulffmorgenthaler","link":"http://wulffmorgenthaler.com/","start":"2011/04/15/","dbfile":dbdir + "comicdb.wulffnew.csv"},
 
 
 
@@ -422,13 +423,19 @@ class ComicDb():
 # fetch earlier
 	def fetch_earlier(self, comic, earliest):
 		print "fetch before, " + comic + " earliest"
-		if comic == "cyanide" or comic == "wulff" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari":
+		if comic == "cyanide" or comic == "babyblues" or comic[-9:] == "comicscom" or comic[-6:] == "hesari":
 			print "getting get_prev_id..."
 			comicid = self.get_prev_id(comic,earliest)
 			if not comicid:
 				print "already at first comic"
 				return
 			print "got " + comicid + " as the one before current..."
+                elif comic == "wulff_new":
+			# date id.
+			dt = string.split(earliest, "/")
+			d = datetime.date(int(dt[0]),int(dt[1]),int(dt[2]))
+			earlier = d - datetime.timedelta( 1 )
+			comicid = earlier.strftime("%Y/%m/%d")
 		elif len(str(earliest)) == 10:
 			# date id.
 			dt = string.split(earliest, "-")
@@ -468,6 +475,12 @@ class ComicDb():
 			if not comicid:
 				print "already at last comic"
 				return
+                elif comic == "wulff_new":
+			# date id.
+			dt = string.split(newest, "/")
+			d = datetime.date(int(dt[0]),int(dt[1]),int(dt[2]))
+			earlier = d + datetime.timedelta( 1 )
+			comicid = earlier.strftime("%Y/%m/%d")
 		elif len(newest) == 10:
 			# date id.
 			dt = string.split(newest, "-")
@@ -841,8 +854,8 @@ class ComicDb():
 			link = "http://www.phdcomics.com/comics/archive.php?comicid=" + str(number)
 		elif comic == 'cyanide':
 			link = "http://www.explosm.net/comics/" + str(number) + "/"
-		elif comic == 'wulff':
-			link = "http://wulffmorgenthaler.com/default.aspx?id=" + str(number)
+		elif comic == 'wulff_new':
+			link = "http://wulffmorgenthaler.com/" + str(number)
 		elif comic == 'babyblues':
 			link = "http://www.babyblues.com/archive/index.php?formname=getstrip&GoToDay=" + str(number)
 		elif comic[-9:] == 'comicscom':	
@@ -979,9 +992,7 @@ class ComicDb():
 			elif comic == 'babyblues':
 				# babyblues is type .gif
 				s = f.read()
-				f.close()
-				splt = string.split(s, 'http://est.rbma.com/content/Baby_Blues?date=', 1)
-				flnm = splt[1][:8]
+				f.clos[:8]
 				# check filename...
 				datesplt = string.split(number, "/")
 				flncheck = datesplt[2] + datesplt[0] + datesplt[1]
@@ -995,29 +1006,24 @@ class ComicDb():
 				return irow
 
 
-			elif comic == 'wulff':
+			elif comic == 'wulff_new':
 				# wulf is type .gif
 				s = f.read()
 				f.close()
-				splt = string.split(s, '<img src="pics/dates/month/', 1)
-				if not splt[1][1:2] == ".":
-					title = splt[1][:2]
-				else:
-					title = "0" + splt[1][:1]
-				splt = string.split(splt[1], '<img src="pics/dates/day/', 1)
-				if not splt[1][1:2] == ".":
-					title = title + "-" + splt[1][:2]
-				else:
-					title = title + "-0" + splt[1][:1]
-				splt = string.split(splt[1], '<img src="pics/dates/year/', 1)
-				title = splt[1][:4] + "-" + title
+				splt = string.split(s, 'Daily strip ', 1)
+				splt = string.split(splt[1], '" />', 1)
 				# title done...
-				splt = string.split(splt[1], 'id="ctl00_content_Strip1_imgStrip" class="strip" src="striphandler.ashx?stripid=', 1)
-				number = splt[1][:36]
-				url = "http://wulffmorgenthaler.com/striphandler.ashx?stripid=" + number
-				filename = number + ".gif"
+				title = splt[0]
+				print "title"
+				splt = string.split(splt[1], '<meta property="og:image" content="', 1)
+				splt = string.split(splt[1], '" />', 1)
+				# url done
+				url = splt[0]
+				splt2 = string.rsplit(url, "/", 1)
+				filename = splt2[1]
 				irow = [comic,number,link,url,filename,title]
 				return irow
+			
 			elif comic[-9:] == 'comicscom':
 				url = self.parse_comics_com(comic, f.read(), 'url') 
 				f.close()
